@@ -7,7 +7,7 @@ Start Date   : 20080513
 
 Description  : Eddie-Tool command-line entry points.
 
-$Id: commands.py 914 2008-05-13 08:13:27Z chris $
+$Id: commands.py 922 2009-01-05 04:49:01Z chris $
 '''
 
 __copyright__ = 'Copyright (c) Chris Miles 2008'
@@ -343,7 +343,7 @@ def doArgs():
     usageMsg = "usage: %prog [options] eddie.cfg"
     versionMsg = """EDDIE Tool %s""" % __version__
     try:
-        versionMsg += " (Build %s)" %'$Revision: 914 $'.split()[1]
+        versionMsg += " (Build %s)" %'$Revision: 922 $'.split()[1]
     except:
         pass
 
@@ -351,20 +351,33 @@ def doArgs():
     parser = optparse.OptionParser(usage=usageMsg, version=versionMsg)
     # parser.add_option('-c', '--config', dest='config',                 \
     #                     metavar="FILE", help="Load config from FILE")
-    parser.add_option('--showconfig', action="store_true",         \
+    parser.add_option('--showconfig', action="store_true",
+                        default=False,
                         help="Dump config")
-    parser.add_option('-v', '--verbose', action="store_true",        \
+    parser.add_option('-v', '--verbose', action="store_true",
+                        default=False,
                         help="Enable verbose output")
-    parser.add_option('-d', '--daemon', action="store_true",        \
+    parser.add_option('-d', '--daemon', action="store_true",
+                        default=False,
                         help="Run as a daemon")
-    parser.set_defaults(showconfig=False, verbose=False,        \
-                        daemon=False)
+    parser.add_option('-S', '--startup-delay', action='store', dest="startup_delay",        \
+                        default=None, metavar="SECONDS",
+                        help="Number of SECONDS to pause at startup before monitoring rule execution commences.")
 
     # Parse.  We dont accept arguments, so we complain if they're found.
     (options, args) = parser.parse_args()
     if len(args) != 1:
         parser.error('Configuration file must be given as first argument.')
 
+    if options.startup_delay is not None:
+        # Check value is acceptable
+        try:
+            value = int(options.startup_delay)
+            if value < 0:
+                raise ValueError()
+        except:
+            parser.error("-S|--startup-delay value must be a positive integer value.")
+    
     # All good - return the option dict
     return (options, args[0])
 
@@ -407,7 +420,7 @@ def main():
     parseConfig.readConf(config_file, Config)
 
     try:
-        buildstr = " (Build %s)" %'$Revision: 914 $'.split()[1]
+        buildstr = " (Build %s)" %'$Revision: 922 $'.split()[1]
     except:
         buildstr = ''
     
@@ -423,6 +436,12 @@ def main():
         print Config
         eddieexit()
 
+    if Options.startup_delay:
+        delay = int(Options.startup_delay)
+        if delay > 0:
+            log.log( "<eddie>main(): pausing %d seconds before executing rules" %delay, 5)
+            time.sleep(delay)
+    
     if Options.daemon:
         # Create a child process, then have the parent exit
         cpid = utils.create_child(True)
